==> zio-aws-swf_2.12-5.17.181.1-sources.jar: zio/aws/swf/model/ActivityTypeConfiguration.scala <==
package zio.aws.swf.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.swf.model.primitives.{TaskPriority, DurationInSecondsOptional}
import scala.jdk.CollectionConverters._
final case class ActivityTypeConfiguration(
    defaultTaskStartToCloseTimeout: Optional[DurationInSecondsOptional] =
      Optional.Absent,
    defaultTaskHeartbeatTimeout: Optional[DurationInSecondsOptional] =
      Optional.Absent,
    defaultTaskList: Optional[zio.aws.swf.model.TaskList] = Optional.Absent,
    defaultTaskPriority: Optional[TaskPriority] = Optional.Absent,
    defaultTaskScheduleToStartTimeout: Optional[DurationInSecondsOptional] =
      Optional.Absent,
    defaultTaskScheduleToCloseTimeout: Optional[DurationInSecondsOptional] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.swf.model.ActivityTypeConfiguration = {
    import ActivityTypeConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.swf.model.ActivityTypeConfiguration
      .builder()
      .optionallyWith(
        defaultTaskStartToCloseTimeout.map(value =>
          DurationInSecondsOptional.unwrap(value): java.lang.String
        )
      )(_.defaultTaskStartToCloseTimeout)
      .optionallyWith(
        defaultTaskHeartbeatTimeout.map(value =>
          DurationInSecondsOptional.unwrap(value): java.lang.String
        )
      )(_.defaultTaskHeartbeatTimeout)
      .optionallyWith(defaultTaskList.map(value => value.buildAwsValue()))(
        _.defaultTaskList
      )
      .optionallyWith(
        defaultTaskPriority.map(value =>
          TaskPriority.unwrap(value): java.lang.String
        )
      )(_.defaultTaskPriority)
      .optionallyWith(
        defaultTaskScheduleToStartTimeout.map(value =>
          DurationInSecondsOptional.unwrap(value): java.lang.String
        )
      )(_.defaultTaskScheduleToStartTimeout)
      .optionallyWith(
        defaultTaskScheduleToCloseTimeout.map(value =>
          DurationInSecondsOptional.unwrap(value): java.lang.String
        )
      )(_.defaultTaskScheduleToCloseTimeout)
      .build()
  }
  def asReadOnly: zio.aws.swf.model.ActivityTypeConfiguration.ReadOnly =
    zio.aws.swf.model.ActivityTypeConfiguration.wrap(buildAwsValue())
}
object ActivityTypeConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.swf.model.ActivityTypeConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.swf.model.ActivityTypeConfiguration =
      zio.aws.swf.model.ActivityTypeConfiguration(
        defaultTaskStartToCloseTimeout.map(value => value),
        defaultTaskHeartbeatTimeout.map(value => value),
        defaultTaskList.map(value => value.asEditable),
        defaultTaskPriority.map(value => value),
        defaultTaskScheduleToStartTimeout.map(value => value),
        defaultTaskScheduleToCloseTimeout.map(value => value)
      )
    def defaultTaskStartToCloseTimeout: Optional[DurationInSecondsOptional]
    def defaultTaskHeartbeatTimeout: Optional[DurationInSecondsOptional]
    def defaultTaskList: Optional[zio.aws.swf.model.TaskList.ReadOnly]
    def defaultTaskPriority: Optional[TaskPriority]
    def defaultTaskScheduleToStartTimeout: Optional[DurationInSecondsOptional]
    def defaultTaskScheduleToCloseTimeout: Optional[DurationInSecondsOptional]
    def getDefaultTaskStartToCloseTimeout
        : ZIO[Any, AwsError, DurationInSecondsOptional] =
      AwsError.unwrapOptionField(
        "defaultTaskStartToCloseTimeout",
        defaultTaskStartToCloseTimeout
      )
    def getDefaultTaskHeartbeatTimeout
        : ZIO[Any, AwsError, DurationInSecondsOptional] =
      AwsError.unwrapOptionField(
        "defaultTaskHeartbeatTimeout",
        defaultTaskHeartbeatTimeout
      )
    def getDefaultTaskList
        : ZIO[Any, AwsError, zio.aws.swf.model.TaskList.ReadOnly] =
      AwsError.unwrapOptionField("defaultTaskList", defaultTaskList)
    def getDefaultTaskPriority: ZIO[Any, AwsError, TaskPriority] =
      AwsError.unwrapOptionField("defaultTaskPriority", defaultTaskPriority)
    def getDefaultTaskScheduleToStartTimeout
        : ZIO[Any, AwsError, DurationInSecondsOptional] =
      AwsError.unwrapOptionField(
        "defaultTaskScheduleToStartTimeout",
        defaultTaskScheduleToStartTimeout
      )
    def getDefaultTaskScheduleToCloseTimeout
        : ZIO[Any, AwsError, DurationInSecondsOptional] =
      AwsError.unwrapOptionField(
        "defaultTaskScheduleToCloseTimeout",
        defaultTaskScheduleToCloseTimeout
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.swf.model.ActivityTypeConfiguration
  ) extends zio.aws.swf.model.ActivityTypeConfiguration.ReadOnly {
    override val defaultTaskStartToCloseTimeout
        : Optional[DurationInSecondsOptional] = zio.aws.core.internal
      .optionalFromNullable(impl.defaultTaskStartToCloseTimeout())
      .map(value =>
        zio.aws.swf.model.primitives.DurationInSecondsOptional(value)
      )
    override val defaultTaskHeartbeatTimeout
        : Optional[DurationInSecondsOptional] = zio.aws.core.internal
      .optionalFromNullable(impl.defaultTaskHeartbeatTimeout())
      .map(value =>
        zio.aws.swf.model.primitives.DurationInSecondsOptional(value)
      )
    override val defaultTaskList
        : Optional[zio.aws.swf.model.TaskList.ReadOnly] = zio.aws.core.internal
      .optionalFromNullable(impl.defaultTaskList())
      .map(value => zio.aws.swf.model.TaskList.wrap(value))
    override val defaultTaskPriority: Optional[TaskPriority] =
      zio.aws.core.internal
        .optionalFromNullable(impl.defaultTaskPriority())
        .map(value => zio.aws.swf.model.primitives.TaskPriority(value))
    override val defaultTaskScheduleToStartTimeout
        : Optional[DurationInSecondsOptional] = zio.aws.core.internal
      .optionalFromNullable(impl.defaultTaskScheduleToStartTimeout())
      .map(value =>
        zio.aws.swf.model.primitives.DurationInSecondsOptional(value)
      )
    override val defaultTaskScheduleToCloseTimeout
        : Optional[DurationInSecondsOptional] = zio.aws.core.internal
      .optionalFromNullable(impl.defaultTaskScheduleToCloseTimeout())
      .map(value =>
        zio.aws.swf.model.primitives.DurationInSecondsOptional(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.swf.model.ActivityTypeConfiguration
  ): zio.aws.swf.model.ActivityTypeConfiguration.ReadOnly = new Wrapper(impl)
}

==> zio-aws-swf_2.13-5.17.153.1-sources.jar: zio/aws/swf/model/ActivityTypeConfiguration.scala <==
package zio.aws.swf.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.swf.model.primitives.{TaskPriority, DurationInSecondsOptional}
import scala.jdk.CollectionConverters._
final case class ActivityTypeConfiguration(
    defaultTaskStartToCloseTimeout: Option[DurationInSecondsOptional] = None,
    defaultTaskHeartbeatTimeout: Option[DurationInSecondsOptional] = None,
    defaultTaskList: Option[zio.aws.swf.model.TaskList] = None,
    defaultTaskPriority: Option[TaskPriority] = None,
    defaultTaskScheduleToStartTimeout: Option[DurationInSecondsOptional] = None,
    defaultTaskScheduleToCloseTimeout: Option[DurationInSecondsOptional] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.swf.model.ActivityTypeConfiguration = {
    import ActivityTypeConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.swf.model.ActivityTypeConfiguration
      .builder()
      .optionallyWith(
        defaultTaskStartToCloseTimeout.map(value =>
          DurationInSecondsOptional.unwrap(value): java.lang.String
        )
      )(_.defaultTaskStartToCloseTimeout)
      .optionallyWith(
        defaultTaskHeartbeatTimeout.map(value =>
          DurationInSecondsOptional.unwrap(value): java.lang.String
        )
      )(_.defaultTaskHeartbeatTimeout)
      .optionallyWith(defaultTaskList.map(value => value.buildAwsValue()))(
        _.defaultTaskList
      )
      .optionallyWith(
        defaultTaskPriority.map(value =>
          TaskPriority.unwrap(value): java.lang.String
        )
      )(_.defaultTaskPriority)
      .optionallyWith(
        defaultTaskScheduleToStartTimeout.map(value =>
          DurationInSecondsOptional.unwrap(value): java.lang.String
        )
      )(_.defaultTaskScheduleToStartTimeout)
      .optionallyWith(
        defaultTaskScheduleToCloseTimeout.map(value =>
          DurationInSecondsOptional.unwrap(value): java.lang.String
        )
      )(_.defaultTaskScheduleToCloseTimeout)
      .build()
  }
  def asReadOnly: zio.aws.swf.model.ActivityTypeConfiguration.ReadOnly =
    zio.aws.swf.model.ActivityTypeConfiguration.wrap(buildAwsValue())
}
object ActivityTypeConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.swf.model.ActivityTypeConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.swf.model.ActivityTypeConfiguration =
      zio.aws.swf.model.ActivityTypeConfiguration(
        defaultTaskStartToCloseTimeout.map(value => value),
        defaultTaskHeartbeatTimeout.map(value => value),
        defaultTaskList.map(value => value.asEditable),
        defaultTaskPriority.map(value => value),
        defaultTaskScheduleToStartTimeout.map(value => value),
        defaultTaskScheduleToCloseTimeout.map(value => value)
      )
    def defaultTaskStartToCloseTimeout: Option[DurationInSecondsOptional]
    def defaultTaskHeartbeatTimeout: Option[DurationInSecondsOptional]
    def defaultTaskList: Option[zio.aws.swf.model.TaskList.ReadOnly]
    def defaultTaskPriority: Option[TaskPriority]
    def defaultTaskScheduleToStartTimeout: Option[DurationInSecondsOptional]
    def defaultTaskScheduleToCloseTimeout: Option[DurationInSecondsOptional]
    def getDefaultTaskStartToCloseTimeout
        : ZIO[Any, AwsError, DurationInSecondsOptional] =
      AwsError.unwrapOptionField(
        "defaultTaskStartToCloseTimeout",
        defaultTaskStartToCloseTimeout
      )
    def getDefaultTaskHeartbeatTimeout
        : ZIO[Any, AwsError, DurationInSecondsOptional] =
      AwsError.unwrapOptionField(
        "defaultTaskHeartbeatTimeout",
        defaultTaskHeartbeatTimeout
      )
    def getDefaultTaskList
        : ZIO[Any, AwsError, zio.aws.swf.model.TaskList.ReadOnly] =
      AwsError.unwrapOptionField("defaultTaskList", defaultTaskList)
    def getDefaultTaskPriority: ZIO[Any, AwsError, TaskPriority] =
      AwsError.unwrapOptionField("defaultTaskPriority", defaultTaskPriority)
    def getDefaultTaskScheduleToStartTimeout
        : ZIO[Any, AwsError, DurationInSecondsOptional] =
      AwsError.unwrapOptionField(
        "defaultTaskScheduleToStartTimeout",
        defaultTaskScheduleToStartTimeout
      )
    def getDefaultTaskScheduleToCloseTimeout
        : ZIO[Any, AwsError, DurationInSecondsOptional] =
      AwsError.unwrapOptionField(
        "defaultTaskScheduleToCloseTimeout",
        defaultTaskScheduleToCloseTimeout
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.swf.model.ActivityTypeConfiguration
  ) extends zio.aws.swf.model.ActivityTypeConfiguration.ReadOnly {
    override val defaultTaskStartToCloseTimeout
        : Option[DurationInSecondsOptional] = scala
      .Option(impl.defaultTaskStartToCloseTimeout())
      .map(value =>
        zio.aws.swf.model.primitives.DurationInSecondsOptional(value)
      )
    override val defaultTaskHeartbeatTimeout
        : Option[DurationInSecondsOptional] = scala
      .Option(impl.defaultTaskHeartbeatTimeout())
      .map(value =>
        zio.aws.swf.model.primitives.DurationInSecondsOptional(value)
      )
    override val defaultTaskList: Option[zio.aws.swf.model.TaskList.ReadOnly] =
      scala
        .Option(impl.defaultTaskList())
        .map(value => zio.aws.swf.model.TaskList.wrap(value))
    override val defaultTaskPriority: Option[TaskPriority] = scala
      .Option(impl.defaultTaskPriority())
      .map(value => zio.aws.swf.model.primitives.TaskPriority(value))
    override val defaultTaskScheduleToStartTimeout
        : Option[DurationInSecondsOptional] = scala
      .Option(impl.defaultTaskScheduleToStartTimeout())
      .map(value =>
        zio.aws.swf.model.primitives.DurationInSecondsOptional(value)
      )
    override val defaultTaskScheduleToCloseTimeout
        : Option[DurationInSecondsOptional] = scala
      .Option(impl.defaultTaskScheduleToCloseTimeout())
      .map(value =>
        zio.aws.swf.model.primitives.DurationInSecondsOptional(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.swf.model.ActivityTypeConfiguration
  ): zio.aws.swf.model.ActivityTypeConfiguration.ReadOnly = new Wrapper(impl)
}
